@@ -1,4 +1,4 @@
-# Copyright (c) 2020, Riverbank Computing Limited
+# Copyright (c) 2021, Riverbank Computing Limited
 # All rights reserved.
 #
 # This copy of PyQt-builder is licensed for use under the terms of the SIP
@@ -24,6 +24,7 @@
 
 import os
 import sys
+import sysconfig
 
 from sipbuild import (Buildable, BuildableModule, Builder, Option, Project,
         PyProjectOptionException, UserException)
@@ -103,15 +104,26 @@ class QmakeBuilder(Builder):
                 py_platform = 'wasm'
             elif 'win32' in xspec:
                 py_platform = 'win32'
+            elif 'mingw-w64' in xspec:
+                py_platform = 'win32'
             else:
                 # Treat everything else as Linux.
                 py_platform = 'linux'
 
             project.py_platform = py_platform
 
+            # Set the default minimum GLIBC version.
+            if not project.minimum_glibc_version:
+                if self.qt_version >= 0x060000:
+                    project.minimum_glibc_version = '2.28'
+                else:
+                    project.minimum_glibc_version = '2.17'
+
             # Set the default minimum macOS version.
             if not project.minimum_macos_version:
-                if self.qt_version >= 0x050e00:
+                if self.qt_version >= 0x060000:
+                    project.minimum_macos_version = '10.14'
+                elif self.qt_version >= 0x050e00:
                     project.minimum_macos_version = '10.13'
                 elif self.qt_version >= 0x050c00:
                     project.minimum_macos_version = '10.12'
@@ -128,10 +140,18 @@ class QmakeBuilder(Builder):
 
             # Set the default ABI version of the sip module.
             if not project.abi_version:
+                # The defaults should really be the .0 versions but we
+                # originally didn't specify a minor version so that SIP
+                # defaulted to the latest version it knew about (which may vary
+                # according to the SIP version).  We therefore specify the
+                # minimum version needed by the current versions of PyQt at the
+                # time of writing.  If later versions of PyQt have different
+                # requirements then they will explicitly specify the required
+                # version.
                 if project.sip_module == 'PyQt5.sip':
-                    project.abi_version = '12'
+                    project.abi_version = '12.8'
                 elif project.sip_module == 'PyQt6.sip':
-                    project.abi_version = '13'
+                    project.abi_version = '13.1'
 
         super().apply_user_defaults(tool)
 
@@ -319,8 +339,8 @@ class QmakeBuilder(Builder):
         """ Return the name of a valid make program. """
 
         if self.project.py_platform == 'win32':
-            if self.spec == 'win32-g++':
-                make = 'mingw32-make'
+            if 'g++' in self.spec:
+                make = 'make'
             else:
                 make = 'nmake'
         else:
@@ -660,6 +680,13 @@ macx {
 
         buildable.make_names_relative()
 
+        # Handle the target architecture(s).  The way that Python handles
+        # 'universal2' seems broken as it is determined by what versions of
+        # macOS and the SDK the interpreter was built against rather than the
+        # versions that are being used now.
+        if self.project.get_platform_tag().endswith('_universal2'):
+            pro_lines.append('QMAKE_APPLE_DEVICE_ARCHS = x86_64 arm64')
+
         # Handle debugging.
         pro_lines.append(
                 'CONFIG += {}'.format(
